#![warn(
    clippy::all,
/*    clippy::restriction,*/
    clippy::pedantic,
    clippy::nursery,
    clippy::cargo
)]
#![allow(clippy::non_ascii_literal)]

use log::warn;
use regex::Regex;

use crate::userlib_error::UserLibError;
use std::cmp::Eq;
use std::convert::TryFrom;
use std::fmt::{self, Display};
use std::io::{BufRead, Read};

pub struct UserDBLocal<'a> {
    pub(crate) passwd_entries: Vec<crate::Passwd<'a>>,
    pub(crate) shadow_entries: Vec<crate::Shadow<'a>>,
    pub(crate) group_entries: Vec<crate::Group<'a>>,
}

impl<'a> UserDBLocal<'a> {
    #[must_use]
    pub fn import_from_strings(
        passwd_content: &'a str,
        shadow_content: &'a str,
        group_content: &'a str,
    ) -> Self {
        let res = UserDBLocal {
            passwd_entries: passwd_content
                .lines()
                .map(|line| crate::Passwd::new_from_string(line).expect("failed to read lines"))
                .collect(),
            group_entries: group_content
                .lines()
                .map(|line| crate::Group::new_from_string(line).expect("Parsing failed"))
                .collect(),
            shadow_entries: shadow_content
                .lines()
                .map(|line| crate::Shadow::new_from_string(line).expect("Parsing failed"))
                .collect(),
        };
        res
    }
}

#[test]
fn test_creator_user_db_local() {
    let data = UserDBLocal::import_from_strings("testuser:x:1001:1001:full Name,004,000342,001-2312,myemail@test.com:/home/test:/bin/test", "test:!!$6$/RotIe4VZzzAun4W$7YUONvru1rDnllN5TvrnOMsWUD5wSDUPAD6t6/Xwsr/0QOuWF3HcfAhypRkGa8G1B9qqWV5kZSnCb8GKMN9N61:18260:0:99999:7:::", "teste:x:1002:test,teste");
    assert_eq!(
        data.passwd_entries.get(0).unwrap().get_username(),
        "testuser"
    )
}
